# Test Suite

- Framework
- SysOfEqn
- Element
- UniaxialMaterial
- nDMaterial
- Backbone

## Pure Python

### Level 2 - Model building correctness

### Level 3 - Analysis Correctness

## libOpenSeesRT

### Level 1 - Memory / Safety

### Level 2 - Model building correctness

### Level 3 - Analysis Correctness

### Level 4 - Analysis Stability

## libOpenSeesPyRT

### Level 1 - Memory / Safety

### Level 2 - Serialization

### Level 3 - Analysis Correctness

